FFTW 3.3.4: Multi-dimensional Array Format

Next: Words of Wisdom-Saving Plans, Previous: SIMD alignment and fftw_malloc, Up: Other Important Topics [Contents][Index]

### 3.2 Multi-dimensional Array Format

This section describes the format in which multi-dimensional arrays are stored in FFTW. We felt that a detailed discussion of this topic was necessary. Since several different formats are common, this topic is often a source of confusion.